@@ -9,7 +9,7 @@ if TYPE_CHECKING:
     from typing import Any
 
 
-async def sa_init_db(
+async def init_db(
     app: 'Application',
     metadata: 'MetaData',
     key: str = SA_DEFAULT_KEY,
@@ -20,5 +20,13 @@ async def sa_init_db(
         await connection.run_sync(metadata.create_all)
 
 
+async def sa_init_db(
+    app: 'Application',
+    metadata: 'MetaData',
+    key: str = SA_DEFAULT_KEY,
+) -> None:
+    await init_db(app, metadata, key)
+
+
 def sa_session(request: 'Request', key: str = SA_DEFAULT_KEY) -> 'AsyncSession':
     return request[key]
